==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/AuthenticationStatusFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class AuthenticationStatusFluentImpl<A extends io.fabric8.openshift.api.model.AuthenticationStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.AuthenticationStatusFluent<A>{
  public AuthenticationStatusFluentImpl() {
  }
  public AuthenticationStatusFluentImpl(io.fabric8.openshift.api.model.AuthenticationStatus instance) {
    this.withIntegratedOAuthMetadata(instance.getIntegratedOAuthMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder integratedOAuthMetadata;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildIntegratedOAuthMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ConfigMapNameReference getIntegratedOAuthMetadata() {
    return this.integratedOAuthMetadata!=null?this.integratedOAuthMetadata.build():null;
  }
  public io.fabric8.openshift.api.model.ConfigMapNameReference buildIntegratedOAuthMetadata() {
    return this.integratedOAuthMetadata!=null?this.integratedOAuthMetadata.build():null;
  }
  public A withIntegratedOAuthMetadata(io.fabric8.openshift.api.model.ConfigMapNameReference integratedOAuthMetadata) {
    _visitables.get("integratedOAuthMetadata").remove(this.integratedOAuthMetadata);
    if (integratedOAuthMetadata!=null){ this.integratedOAuthMetadata= new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(integratedOAuthMetadata); _visitables.get("integratedOAuthMetadata").add(this.integratedOAuthMetadata);} return (A) this;
  }
  public java.lang.Boolean hasIntegratedOAuthMetadata() {
    return this.integratedOAuthMetadata != null;
  }
  public A withNewIntegratedOAuthMetadata(java.lang.String name) {
    return (A)withIntegratedOAuthMetadata(new ConfigMapNameReference(name));
  }
  public io.fabric8.openshift.api.model.AuthenticationStatusFluent.IntegratedOAuthMetadataNested<A> withNewIntegratedOAuthMetadata() {
    return new io.fabric8.openshift.api.model.AuthenticationStatusFluentImpl.IntegratedOAuthMetadataNestedImpl();
  }
  public io.fabric8.openshift.api.model.AuthenticationStatusFluent.IntegratedOAuthMetadataNested<A> withNewIntegratedOAuthMetadataLike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
    return new io.fabric8.openshift.api.model.AuthenticationStatusFluentImpl.IntegratedOAuthMetadataNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.AuthenticationStatusFluent.IntegratedOAuthMetadataNested<A> editIntegratedOAuthMetadata() {
    return withNewIntegratedOAuthMetadataLike(getIntegratedOAuthMetadata());
  }
  public io.fabric8.openshift.api.model.AuthenticationStatusFluent.IntegratedOAuthMetadataNested<A> editOrNewIntegratedOAuthMetadata() {
    return withNewIntegratedOAuthMetadataLike(getIntegratedOAuthMetadata() != null ? getIntegratedOAuthMetadata(): new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.AuthenticationStatusFluent.IntegratedOAuthMetadataNested<A> editOrNewIntegratedOAuthMetadataLike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
    return withNewIntegratedOAuthMetadataLike(getIntegratedOAuthMetadata() != null ? getIntegratedOAuthMetadata(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AuthenticationStatusFluentImpl that = (AuthenticationStatusFluentImpl) o;
    if (integratedOAuthMetadata != null ? !integratedOAuthMetadata.equals(that.integratedOAuthMetadata) :that.integratedOAuthMetadata != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(integratedOAuthMetadata,  additionalProperties,  super.hashCode());
  }
  public class IntegratedOAuthMetadataNestedImpl<N> extends io.fabric8.openshift.api.model.ConfigMapNameReferenceFluentImpl<io.fabric8.openshift.api.model.AuthenticationStatusFluent.IntegratedOAuthMetadataNested<N>> implements io.fabric8.openshift.api.model.AuthenticationStatusFluent.IntegratedOAuthMetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    IntegratedOAuthMetadataNestedImpl(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this, item);
    }
    IntegratedOAuthMetadataNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder builder;
    public N and() {
      return (N) AuthenticationStatusFluentImpl.this.withIntegratedOAuthMetadata(builder.build());
    }
    public N endIntegratedOAuthMetadata() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.12.3-sources.jar: io/fabric8/openshift/api/model/AuthenticationStatusFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class AuthenticationStatusFluentImpl<A extends io.fabric8.openshift.api.model.AuthenticationStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.AuthenticationStatusFluent<A>{
  public AuthenticationStatusFluentImpl() {
  }
  public AuthenticationStatusFluentImpl(io.fabric8.openshift.api.model.AuthenticationStatus instance) {
    this.withIntegratedOAuthMetadata(instance.getIntegratedOAuthMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder integratedOAuthMetadata;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildIntegratedOAuthMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ConfigMapNameReference getIntegratedOAuthMetadata() {
    return this.integratedOAuthMetadata!=null?this.integratedOAuthMetadata.build():null;
  }
  public io.fabric8.openshift.api.model.ConfigMapNameReference buildIntegratedOAuthMetadata() {
    return this.integratedOAuthMetadata!=null?this.integratedOAuthMetadata.build():null;
  }
  public A withIntegratedOAuthMetadata(io.fabric8.openshift.api.model.ConfigMapNameReference integratedOAuthMetadata) {
    _visitables.get("integratedOAuthMetadata").remove(this.integratedOAuthMetadata);
    if (integratedOAuthMetadata!=null){ this.integratedOAuthMetadata= new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(integratedOAuthMetadata); _visitables.get("integratedOAuthMetadata").add(this.integratedOAuthMetadata);} return (A) this;
  }
  public java.lang.Boolean hasIntegratedOAuthMetadata() {
    return this.integratedOAuthMetadata != null;
  }
  public A withNewIntegratedOAuthMetadata(java.lang.String name) {
    return (A)withIntegratedOAuthMetadata(new ConfigMapNameReference(name));
  }
  public io.fabric8.openshift.api.model.AuthenticationStatusFluent.IntegratedOAuthMetadataNested<A> withNewIntegratedOAuthMetadata() {
    return new io.fabric8.openshift.api.model.AuthenticationStatusFluentImpl.IntegratedOAuthMetadataNestedImpl();
  }
  public io.fabric8.openshift.api.model.AuthenticationStatusFluent.IntegratedOAuthMetadataNested<A> withNewIntegratedOAuthMetadataLike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
    return new io.fabric8.openshift.api.model.AuthenticationStatusFluentImpl.IntegratedOAuthMetadataNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.AuthenticationStatusFluent.IntegratedOAuthMetadataNested<A> editIntegratedOAuthMetadata() {
    return withNewIntegratedOAuthMetadataLike(getIntegratedOAuthMetadata());
  }
  public io.fabric8.openshift.api.model.AuthenticationStatusFluent.IntegratedOAuthMetadataNested<A> editOrNewIntegratedOAuthMetadata() {
    return withNewIntegratedOAuthMetadataLike(getIntegratedOAuthMetadata() != null ? getIntegratedOAuthMetadata(): new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.AuthenticationStatusFluent.IntegratedOAuthMetadataNested<A> editOrNewIntegratedOAuthMetadataLike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
    return withNewIntegratedOAuthMetadataLike(getIntegratedOAuthMetadata() != null ? getIntegratedOAuthMetadata(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AuthenticationStatusFluentImpl that = (AuthenticationStatusFluentImpl) o;
    if (integratedOAuthMetadata != null ? !integratedOAuthMetadata.equals(that.integratedOAuthMetadata) :that.integratedOAuthMetadata != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(integratedOAuthMetadata,  additionalProperties,  super.hashCode());
  }
  public class IntegratedOAuthMetadataNestedImpl<N> extends io.fabric8.openshift.api.model.ConfigMapNameReferenceFluentImpl<io.fabric8.openshift.api.model.AuthenticationStatusFluent.IntegratedOAuthMetadataNested<N>> implements io.fabric8.openshift.api.model.AuthenticationStatusFluent.IntegratedOAuthMetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    IntegratedOAuthMetadataNestedImpl(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this, item);
    }
    IntegratedOAuthMetadataNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder builder;
    public N and() {
      return (N) AuthenticationStatusFluentImpl.this.withIntegratedOAuthMetadata(builder.build());
    }
    public N endIntegratedOAuthMetadata() {
      return and();
    }
    
  }
  
}
